# Pika/Torando Example

Connected: {{ connected }}

Every request that your browser makes enqueues a message into RabbitMQ which is then delivered back to the Application's Pika Client. When you poll, you recieve all the messages delivered since your last poll. It will only retain the last 15 messages received.

If you want to enqueue your own messages to be delivered here, just publish to the “tornado” exchange using the routing key of “tornado.*”

## Messages Received Asynchronously from RabbitMQ